/**
 * Transform: delete src/generated/
 *
 * The generated directory is 100% CLI-managed in v1.  In v2 it is gone.
 */
export declare function deleteGeneratedDir(generatedDir: string): void;
//# sourceMappingURL=generated.d.ts.map